---
slug: /do
---

# DO

The `DO` statement executes an SQL expression without returning any result.

The syntax of the `DO` statement is as follows:

```sql
DO expr [, expr ...]
```

In some scenarios, the `DO` statement is equivalent to `SELECT expr` for a quick response without returning results. Here is an example:

```sql
SELECT SLEEP(5);
+----------+
| SLEEP(5) |
+----------+
|        0 |
+----------+
1 row in set (5.001 sec)

DO SLEEP(5);
Query OK, 0 rows affected (5.011 sec)
```